import io, sys, os
import xml.dom.minidom
import xml.etree.ElementTree as ET


#### CREATION OF TEST XML file
root = ET.Element("foundry_data")
ET.SubElement(root,"foundry_name").text = "workflow_library"
ET.SubElement(root,"version_suffix").text = "1.0" # optional suffix
ET.SubElement(root,"process_prefix").text = "" # optional prefix for models
ET.SubElement(root,"NumOfChannel").text = "2" # number of channels for veriloga models
elements = ET.SubElement(root,"element_list")

# elements list
el_list = [

    # elements without statistical data
    ### waveguides
    ["wg_strip_straight_parameterized","wg_parameterized",".json"],
    ["wg_strip_arc_parameterized","wg_parameterized",".json"],
    ["wg_strip_sbend_parameterized","wg_parameterized",".json"],

    ### passives
    ["y_branch_strip_te_c","spar_fixed",".json"],

    ### actives
    ["ps_pn_te_c","phase_shifter_electrical",".json"],

    ### advanced models


    # elements with statistical data
    ["wg_stat_strip_straight_parameterized","wg_parameterized",".json"],
    ["wg_stat_strip_arc_parameterized","wg_parameterized",".json"],
    ["wg_stat_strip_sbend_parameterized","wg_parameterized",".json"],
    ["ps_pn_stat_te_c","phase_shifter_electrical",".json"]

]

# extra information for container elements. List of sub-elements, and the Lumerical script code required to select them
ce_info = {}

ce_info_remove_elements = {}

# Reporting tuned parameters in actives (optional)
#report_tuning = ET.SubElement(root,"report_tuned_data")
#ET.SubElement(report_tuning,"password").text = "!Passcode101" # any alphanumeric password except "NULL" 
                           
# statistical data
stat_data = ET.SubElement(root,"statistical_data")
ET.SubElement(stat_data,"statistical_parameter_status").text = "open" # options: "open", "hidden", "protected"
ET.SubElement(stat_data,"nominal_value_type").text = "mode" # options: "mean", "mode"
# GLOBALGROUP list  ['name','distribution','sigma','gamma1','beta2']  'gamma1' and 'beta2' are needed for pearson4 distribution type only
globalgroup_list = [
    ['global_delta_width','normal','1'],
    ['global_delta_height','normal','1'],
    ['global_delta_ridge_height','normal','1']
]
# CORRGROUP list  ['name','correlation length (m)']
corrgroup_list = [
    ['corr_delta_width','3e-3'],
    ['corr_delta_height','1e-2'],
    ['corr_delta_ridge_height','3e-3']
]
corner_list = ['corner_1','corner_2'] # list all corners

# do not modify
for e in el_list:
    el = ET.SubElement(elements,"element")
    ET.SubElement(el,"name").text = e[0]
    ET.SubElement(el,"photonic_model").text = e[1]
    ET.SubElement(el,"svg_filename").text = "source/"+e[0]+"/"+e[0]+".svg"
    ET.SubElement(el,"parameter_filename").text = "source/"+e[0]+"/"+e[0]+e[2]
    ET.SubElement(el,"datafile_directory").text = "source/"+e[0]
    if e[0] in ce_info.keys():
        if e[0] in ce_info_remove_elements:
            ET.SubElement(el,"remove_sub_elements").text = str(ce_info_remove_elements[e[0]]);
        sub_elements = ET.SubElement(el,"sub_element_list")
        for c in ce_info[e[0]]:
            ce = ET.SubElement(sub_elements,"sub_element")
            ET.SubElement(ce,"name").text = c[0]
            ET.SubElement(ce,"selection_code").text = c[1]
if globalgroup_list:
    lg_list = ET.SubElement(stat_data,"GLOBALGROUP_list")
    for lg in globalgroup_list:
        globalgroup = ET.SubElement(lg_list,"GLOBALGROUP")
        ET.SubElement(globalgroup,"name").text = lg[0]
        ET.SubElement(globalgroup,"distribution").text = lg[1]
        ET.SubElement(globalgroup,"sigma").text = lg[2]
        if lg[1]=='pearson4':
            ET.SubElement(globalgroup,"gamma1").text = lg[3]
            ET.SubElement(globalgroup,"beta2").text = lg[4]
if corrgroup_list:
    cg_list = ET.SubElement(stat_data,"CORRGROUP_list")
    for cg in corrgroup_list:
        corrgroup = ET.SubElement(cg_list,"CORRGROUP")
        ET.SubElement(corrgroup,"name").text = cg[0]
        ET.SubElement(corrgroup,"correlation_length").text = cg[1]
if corner_list:
    cn_list = ET.SubElement(stat_data,"corner_list")
    for cn in corner_list:
        ET.SubElement(cn_list,"corner").text = cn

rough_string = ET.tostring(root)
reparsed = xml.dom.minidom.parseString(rough_string)
print(reparsed.toprettyxml(indent="    "))
with open("workflow_library.xml","w") as f:
    f.write(reparsed.toprettyxml(indent="    "))
